## modified plot.misse.states function for using specific cutoff (maxval / minval)
my.plot.misse.states <- function (x, rate.param = "net.div", type = "fan", show.tip.label = TRUE, 
          fsize = 1, legend = "tips", maxval = "", minval = "", ...) 
{
  hisse.results <- x
  if (inherits(hisse.results, what = c("misse.states", "list"))) {
    if (inherits(hisse.results, what = "misse.states")) {
      if (is.null(hisse.results$aic)) {
        hisse.results$aic = 42
      }
      tmp.list <- list()
      tmp.list[[1]] <- hisse.results
      hisse.results <- tmp.list
    }
    else {
      any.other.class <- any(sapply(hisse.results, function(x) !inherits(x, 
                                                                         what = "misse.states")))
      if (any.other.class) 
        stop("All elements of the list 'x' need to be of class 'misse.states'.")
      any.missing <- any(sapply(hisse.results, function(x) is.null(x$aic)))
      if (any.missing) 
        stop("If x is a list, then each reconstruction need to have $aic information in order to make the model average.")
    }
  }
  else {
    stop("x needs to be an object of class 'misse.states'.")
  }
  rate.param <- match.arg(rate.param, c("turnover", "net.div", 
                                        "speciation", "extinction", "extinction.fraction"))
  type <- match.arg(type, c("fan", "phylogram"))
  if (!is.logical(show.tip.label)) 
    stop("show.tip.label needs TRUE or FALSE")
  legend <- match.arg(legend, c("none", "traditional", "tips", 
                                "internal", "all"))
  if (hasArg(do.observed.only)) {
    do.observed.only <- list(...)$do.observed.only
    if (!is.logical(do.observed.only)) 
      stop("do.observed.only needs TRUE or FALSE")
  }
  else {
    do.observed.only <- TRUE
  }
  if (hasArg(rate.colors)) {
    rate.colors <- list(...)$rate.colors
  }
  else {
    rate.colors <- NULL
  }
  if (hasArg(state.colors)) {
    state.colors <- list(...)$state.colors
  }
  else {
    state.colors <- NULL
  }
  if (hasArg(edge.width)) {
    edge.width <- list(...)$edge.width
    if (!is.numeric(edge.width)) 
      stop("edge.width needs a single numeric value")
  }
  else {
    edge.width <- 1
  }
  if (hasArg(width.factor)) {
    width.factor <- list(...)$width.factor
    if (!is.numeric(width.factor)) 
      stop("width.factor needs a single numeric value")
  }
  else {
    width.factor <- 0
  }
  if (hasArg(mar)) {
    mar <- list(...)$mar
    if (!is.numeric(mar)) 
      stop("mar needs a numeric vector")
  }
  else {
    mar <- c(0.1, 0.1, 0.1, 0.1)
  }
  if (hasArg(outline)) {
    outline <- list(...)$outline
    if (!is.logical(outline)) 
      stop("outline needs TRUE or FALSE")
  }
  else {
    outline <- FALSE
  }
  if (hasArg(outline.color)) {
    outline.color <- list(...)$outline.color
  }
  else {
    outline.color <- "gray"
  }
  if (hasArg(rate.range)) {
    rate.range <- list(...)$rate.range
  }
  else {
    rate.range <- NULL
  }
  if (hasArg(swap.underscore)) {
    swap.underscore <- list(...)$swap.underscore
    if (!is.logical(swap.underscore)) 
      stop("swap.underscore needs TRUE or FALSE")
  }
  else {
    swap.underscore <- TRUE
  }
  if (hasArg(lims.percentage.correction)) {
    lims.percentage.correction <- list(...)$lims.percentage.correction
    if (!is.numeric(lims.percentage.correction)) 
      stop("lims.percentage.correction needs a numeric value")
  }
  else {
    lims.percentage.correction <- 0.001
  }
  if (hasArg(legend.position)) {
    legend.position <- list(...)$legend.position
    if (!is.numeric(legend.position)) 
      stop("legend.position needs a numeric vector")
  }
  else {
    legend.position <- c(0, 0.2, 0, 0.2)
  }
  if (hasArg(legend.cex)) {
    legend.cex <- list(...)$legend.cex
    if (!is.numeric(legend.cex)) 
      stop("legend.cex needs a numeric value")
  }
  else {
    legend.cex <- 0.4
  }
  if (hasArg(legend.kernel.rates)) {
    legend.kernel.rates <- list(...)$legend.kernel.rates
  }
  else {
    legend.kernel.rates <- "auto"
  }
  if (hasArg(legend.kernel.states)) {
    legend.kernel.states <- list(...)$legend.kernel.states
  }
  else {
    legend.kernel.states <- "auto"
  }
  if (hasArg(legend.bg)) {
    legend.bg <- list(...)$legend.bg
  }
  else {
    legend.bg <- "cornsilk3"
  }
  old.par <- par(no.readonly = T)
  if (is.null(rate.colors)) {
    rate.colors <- c("blue", "red")
  }
  if (is.null(state.colors)) {
    state.colors <- c("white", "black")
  }
  ### added the truncation value 'maxval'
  rates.tips <- ConvertManyToRate(hisse.results, rate.param, 
                                  "tip.mat")
  rates.tips[rates.tips > maxval] <- maxval
  # rates.tips[rates.tips < minval] <- minval
  rates.internal <- ConvertManyToRate(hisse.results, rate.param, 
                                      "node.mat")
  rates.internal[rates.internal > maxval] <- maxval
  # rates.internal[rates.internal > minval] <- minval
  ### END changes
  states.tips <- NA
  states.internal <- NA
  if (do.observed.only) {
    states.tips <- rep(0, dim(hisse.results[[1]][["tip.mat"]])[1])
    states.internal <- rep(0, dim(hisse.results[[1]][["node.mat"]])[1])
  }
  tree.to.plot <- hisse.results[[1]]$phy
  rate.lims <- range(c(rates.tips, rates.internal))
  if (!is.null(rate.range)) {
    if (min(rate.range) > min(rate.lims) | max(rate.range) < 
        max(rate.lims)) {
      warning(paste("Did not override rate.lims: the specified rate.range (", 
                    rate.range[1], ", ", rate.range[2], ") did not contain all the values for the observed rates (", 
                    rate.lims[1], ", ", rate.lims[2], ")"))
    }
    else {
      rate.lims <- rate.range
    }
  }
  rate.lims[1] <- rate.lims[1] - lims.percentage.correction * 
    abs(rate.lims[1])
  rate.lims[2] <- rate.lims[2] + lims.percentage.correction * 
    abs(rate.lims[2])
  rate.tree <- contMapGivenAnc(tree = tree.to.plot, x = rates.tips, 
                               plot = FALSE, anc.states = rates.internal, lims = rate.lims)
  rate.colors <- colorRampPalette(rate.colors, space = "Lab", interpolate = "spline")(length(rate.tree$cols))
  rate.tree$cols[] <- rate.colors
  par(fig = c(0, 1, 0, 1), new = FALSE)
  plot.contMapHisse(A = rate.tree, B = rate.tree, lwd.factor = width.factor, 
                    fsize = fsize, , add = FALSE, lwd = edge.width, type = type, 
                    mar = mar, direction = "rightwards", offset = NULL, xlim = NULL, 
                    ylim = NULL, hold = TRUE, swap.underscore = swap.underscore, 
                    outline = outline, outline.color = outline.color, show.tiplabels = show.tip.label)
  if (legend != "none") {
    par(fig = legend.position, new = TRUE)
    plot(x = c(-0.1, 1.1), y = c(-1.5, 1.5), xlab = "", ylab = "", 
         bty = "n", type = "n", xaxt = "n", yaxt = "n")
    rect(-0.1, -1.1, 1.1, 1.1, border = NA, col = legend.bg)
    rates.to.plot <- c()
    states.to.plot <- c()
    if (legend == "all" | legend == "tips") {
      rates.to.plot <- append(rates.to.plot, rates.tips)
      states.to.plot <- append(states.to.plot, states.tips)
    }
    if (legend == "all" | legend == "internal") {
      rates.to.plot <- append(rates.to.plot, rates.internal)
      states.to.plot <- append(states.to.plot, states.internal)
    }
    if (legend.kernel.rates == "auto") {
      if (length(unique(rates.to.plot)) <= 4) {
        legend.kernel.rates <- "hist"
      }
      else {
        legend.kernel.rates <- "rectangular"
      }
    }
    if (legend.kernel.states == "auto") {
      if (length(unique(states.to.plot)) <= 4) {
        legend.kernel.states <- "hist"
      }
      else {
        legend.kernel.states <- "rectangular"
      }
    }
    rates.density <- GetNormalizedDensityPlot(rates.to.plot, 
                                              rate.lims, legend.kernel.rates)
    par(lend = 1)
    segments(x0 = rates.density$x, y0 = rep(0, length(rates.density$y)), 
             y1 = rates.density$y, col = rate.colors[1 + as.integer(round((length(rate.colors) - 
                                                                             1) * rates.density$x))], lwd = ifelse(legend.kernel.rates == 
                                                                                                                     "hist", 4, 1))
    text(x = 0, y = 1.2, labels = format(rate.lims[1], digits = 2), 
         cex = legend.cex)
    text(x = 1, y = 1.2, labels = format(rate.lims[2], digits = 2), 
         cex = legend.cex)
    text(x = 0.5, y = 1.2, labels = rate.param, cex = legend.cex)
  }
  par(old.par)
  return(list(rate.tree = rate.tree))
}
environment(my.plot.misse.states) <- asNamespace('hisse')



## and some internal functions used to test for rate limits (for maxval)
my.ConvertManyToRate <- function(hisse.results, rate.param, which.element, AIC.weights=NULL) {
  if( is.null(AIC.weights) ){
    AIC.weights <- GetAICWeights(hisse.results)
  }
  storage.matrix <- matrix(nrow=dim(hisse.results[[1]][[which.element]])[1], ncol=0)
  for (i in sequence(length(hisse.results))) {
    rate.vector <- hisse.results[[i]]$rates.mat[rate.param,]
    storage.matrix <- cbind(storage.matrix, ConvertToRate(x=hisse.results[[i]][[which.element]], rate.vector=rate.vector))
  }
  final.results <- apply(storage.matrix, 1, weighted.mean, w=AIC.weights)
  return(final.results)
}


ConvertToRate <- function(x, rate.vector) {
  x.trimmed <- x[,-1]
  ## Here is the problem!! This will cause the division by infinite!
  x.trimmed <- x.trimmed / rowSums(x.trimmed) #normalize to 1 (which it should be already)
  result.vector <- rep(0, dim(x.trimmed)[1])
  for (i in sequence(dim(x.trimmed)[2])) {
    result.vector <- result.vector + rate.vector[i] * x.trimmed[,i]	#get weighted mean
  }
  names(result.vector) <- x[,1]
  return(result.vector)
}

