## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ##
## Script for the biogeographic analysis used in
## "Evolution of dispersal, habit, and pollination in Africa pushed Apocynaceae diversification after the Eocene-Oligocene climate transition"
## by Bitencourt et al.; written by Nicolai Nürk, Jan 2021 (nuerk[@]uni-bayreuth.de)
## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ## ##


## Analysis (ii) Hypothesis testing ## M3—M7 models of origin of Apocynaceae ## ## ## ## ## ## ## ## ## 



####################################################
## set time slice (TS) 4 based on the *M2* model:
## allow only very restrictively selected range states for the root node (the single node in TS4)
## to obtain goodness-of-fit of models of origin (of Apocynaceae)
####################

## INPUT the *stratum-specific states list* into the model.def.TS (aka BioGeoBEARS_run_object), i.e. the *M.TS* models

## INPUT — general DEC text model (M.test):
## using for ST1 to TS3 all range states (M2.dec, see below for M2s.dec models)
M.test.dec <- M2.dec
M.test.dec$lists_of_states_lists_0based[[1]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57
M.test.dec$lists_of_states_lists_0based[[2]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57
M.test.dec$lists_of_states_lists_0based[[3]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57

## INPUT — general BAY
## using for ST1 to TS3 all range states (M2.bay)
M.test.bay <- M2.bay
M.test.bay$lists_of_states_lists_0based[[1]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57
M.test.bay$lists_of_states_lists_0based[[2]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57
M.test.bay$lists_of_states_lists_0based[[3]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57

## INPUT — general DIVA
## using for ST1 to TS3 all range states (M2.diva)
M.test.diva <- M2.diva
M.test.diva$lists_of_states_lists_0based[[1]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57
M.test.diva$lists_of_states_lists_0based[[2]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57
M.test.diva$lists_of_states_lists_0based[[3]] <- states_list[ranges_list %in% c(NA) == FALSE] # keep all 57


## INPUT — DEC
## M3: DEC
M3.dec <- M.test.dec
M3.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M3 # keep "SAm" only
check_BioGeoBEARS_run(M3.dec)
## M4: DEC
M4.dec <- M.test.dec
M4.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M4 # keep "AF"
check_BioGeoBEARS_run(M4.dec)
## M5: DEC
M5.dec <- M.test.dec
M5.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M5 # keep SAm", "AF", "SAmAF"
check_BioGeoBEARS_run(M5.dec)
## M6: DEC
M6.dec <- M.test.dec
M6.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M6 # keep "SAm", "AF", "OZ", "SAmAF", "SAmOZ", "AFOZ", "SAmAFOZ"
check_BioGeoBEARS_run(M6.dec)
## M7: DEC
M7.dec <- M.test.dec
M7.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M7 # keep "AStrp"
check_BioGeoBEARS_run(M7.dec)
## M8: DEC
M8.dec <- M.test.dec
M8.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M8 # keep "AStrp", "OZ"
check_BioGeoBEARS_run(M8.dec)
## M9: DEC
M9.dec <- M.test.dec
M9.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M9 # keep "NAm", "EU"
check_BioGeoBEARS_run(M9.dec)
## M10: DEC
M10.dec <- M.test.dec
M10.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M10 # keep "NAm", "AStrp", "EU"
check_BioGeoBEARS_run(M10.dec)
## M11: DEC
M11.dec <- M.test.dec
M11.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M11 # keep "SAm", "AF", "AStrp", "SAmAF", "SAmAStrp", "AFAStrp", "SAmAFAStrp"
check_BioGeoBEARS_run(M11.dec)
## M12: DEC
M12.dec <- M.test.dec
M12.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M12 # keep "SAm", "AF", "OZ", "AStrp", and combinations…
check_BioGeoBEARS_run(M12.dec)



## INPUT — Bayarea
## M3: bay
M3.bay <- M.test.bay
M3.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M3 # keep "SAm" only
check_BioGeoBEARS_run(M3.bay)
## M4: bay
M4.bay <- M.test.bay
M4.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M4 # keep "AF"
check_BioGeoBEARS_run(M4.bay)
## M5: bay
M5.bay <- M.test.bay
M5.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M5 # keep SAm", "AF", "SAmAF"
check_BioGeoBEARS_run(M5.bay)
## M6: bay
M6.bay <- M.test.bay
M6.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M6 # keep "SAm", "AF", "OZ", "SAmAF", "SAmOZ", "AFOZ", "SAmAFOZ"
check_BioGeoBEARS_run(M6.bay)
## M7: bay
M7.bay <- M.test.bay
M7.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M7 # keep "AStrp"
check_BioGeoBEARS_run(M7.bay)
## M8: bay
M8.bay <- M.test.bay
M8.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M8 # keep "AStrp", "OZ"
check_BioGeoBEARS_run(M8.bay)
## M9: bay
M9.bay <- M.test.bay
M9.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M9 # keep "NAm", "EU"
check_BioGeoBEARS_run(M9.bay)
## M10: bay
M10.bay <- M.test.bay
M10.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M10 # keep "NAm", "AStrp", "EU"
check_BioGeoBEARS_run(M10.bay)
## M11: bay
M11.bay <- M.test.bay
M11.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M11 # keep "SAm", "AF", "AStrp", "SAmAF", "SAmAStrp", "AFAStrp", "SAmAFAStrp"
check_BioGeoBEARS_run(M11.bay)
## M12: bay
M12.bay <- M.test.bay
M12.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M12 # keep "SAm", "AF", "OZ", "AStrp", and combinations…
check_BioGeoBEARS_run(M12.bay)


## INPUT — DIVA-like
## M3: diva
M3.diva <- M.test.diva
M3.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M3 # keep "SAm" only
check_BioGeoBEARS_run(M3.diva)
## M4: diva
M4.diva <- M.test.diva
M4.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M4 # keep "AF"
check_BioGeoBEARS_run(M4.diva)
## M5: diva
M5.diva <- M.test.diva
M5.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M5 # keep SAm", "AF", "SAmAF"
check_BioGeoBEARS_run(M5.diva)
## M6: diva
M6.diva <- M.test.diva
M6.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M6 # keep "SAm", "AF", "OZ", "SAmAF", "SAmOZ", "AFOZ", "SAmAFOZ"
check_BioGeoBEARS_run(M6.diva)
## M7: diva
M7.diva <- M.test.diva
M7.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M7 # keep "AStrp"
check_BioGeoBEARS_run(M7.diva)
## M8: diva
M8.diva <- M.test.diva
M8.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M8 # keep "AStrp", "OZ"
check_BioGeoBEARS_run(M8.diva)
## M9: diva
M9.diva <- M.test.diva
M9.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M9 # keep "NAm", "EU"
check_BioGeoBEARS_run(M9.diva)
## M10: diva
M10.diva <- M.test.diva
M10.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M10 # keep "NAm", "AStrp", "EU"
check_BioGeoBEARS_run(M10.diva)
## M11: diva
M11.diva <- M.test.diva
M11.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M11 # keep "SAm", "AF", "AStrp", "SAmAF", "SAmAStrp", "AFAStrp", "SAmAFAStrp"
check_BioGeoBEARS_run(M11.diva)
## M12: diva
M12.diva <- M.test.diva
M12.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M12 # keep "SAm", "AF", "OZ", "AStrp", and combinations…
check_BioGeoBEARS_run(M12.diva)
####################################################



####################################################
## set time slice (TS) 4 based on the *M2.s* model:
## allow only very restrictively selected range states for the root node (the single node in TS4)
## to obtain goodness-of-fit of models of origin (of Apocynaceae)
####################

## INPUT the *stratum-specific states list* into the model.def.TS (aka BioGeoBEARS_run_object)

## INPUT — general DEC text model (M.test):
## using for ST1 to TS3 selected range states (M2s.dec)
Ms.test.dec <- M2s.dec

## INPUT — general BAY
## using for ST1 to TS3 selected range states (M2s.bay)
Ms.test.bay <- M2s.bay

## INPUT — general DIVA
## using for ST1 to TS3 selected range states (M2s.diva)
Ms.test.diva <- M2s.diva



## INPUT — DEC
## M3s: DEC
M3s.dec <- M.test.dec
M3s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M3 # keep "SAm" only
check_BioGeoBEARS_run(M3s.dec)
## M4s: DEC
M4s.dec <- M.test.dec
M4s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M4 # keep "AF"
check_BioGeoBEARS_run(M4s.dec)
## M5s: DEC
M5s.dec <- M.test.dec
M5s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M5 # keep SAm", "AF", "SAmAF"
check_BioGeoBEARS_run(M5s.dec)
## M6s: DEC
M6s.dec <- M.test.dec
M6s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M6 # keep "SAm", "AF", "OZ", "SAmAF", "SAmOZ", "AFOZ", "SAmAFOZ"
check_BioGeoBEARS_run(M6s.dec)
## M7s: DEC
M7s.dec <- M.test.dec
M7s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M7 # keep "AStrp"
check_BioGeoBEARS_run(M7s.dec)
## M8s: DEC
M8s.dec <- M.test.dec
M8s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M8 # keep "AStrp", "OZ"
check_BioGeoBEARS_run(M8s.dec)
## M9s: DEC
M9s.dec <- M.test.dec
M9s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M9 # keep "NAm", "EU"
check_BioGeoBEARS_run(M9s.dec)
## M10s: DEC
M10s.dec <- M.test.dec
M10s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M10 # keep "NAm", "AStrp", "EU"
check_BioGeoBEARS_run(M10s.dec)
## M11s: DEC
M11s.dec <- M.test.dec
M11s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M11 # keep "SAm", "AF", "AStrp", "SAmAF", "SAmAStrp", "AFAStrp", "SAmAFAStrp"
check_BioGeoBEARS_run(M11s.dec)
## M12s: DEC
M12s.dec <- M.test.dec
M12s.dec$lists_of_states_lists_0based[[4]] <- states_list.TS4.M12 # keep "SAm", "AF", "OZ", "AStrp", and combinations…
check_BioGeoBEARS_run(M12s.dec)



## INPUT — Bayarea
## M3s: bay
M3s.bay <- M.test.bay
M3s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M3 # keep "SAm" only
check_BioGeoBEARS_run(M3s.bay)
## M4s: bay
M4s.bay <- M.test.bay
M4s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M4 # keep "AF"
check_BioGeoBEARS_run(M4s.bay)
## M5s: bay
M5s.bay <- M.test.bay
M5s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M5 # keep SAm", "AF", "SAmAF"
check_BioGeoBEARS_run(M5s.bay)
## M6s: bay
M6s.bay <- M.test.bay
M6s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M6 # keep "SAm", "AF", "OZ", "SAmAF", "SAmOZ", "AFOZ", "SAmAFOZ"
check_BioGeoBEARS_run(M6s.bay)
## M7s: bay
M7s.bay <- M.test.bay
M7s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M7 # keep "AStrp"
check_BioGeoBEARS_run(M7s.bay)
## M8s: bay
M8s.bay <- M.test.bay
M8s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M8 # keep "AStrp", "OZ"
check_BioGeoBEARS_run(M8s.bay)
## M9s: bay
M9s.bay <- M.test.bay
M9s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M9 # keep "NAm", "EU"
check_BioGeoBEARS_run(M9s.bay)
## M10s: bay
M10s.bay <- M.test.bay
M10s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M10 # keep "NAm", "AStrp", "EU"
check_BioGeoBEARS_run(M10s.bay)
## M11s: bay
M11s.bay <- M.test.bay
M11s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M11 # keep "SAm", "AF", "AStrp", "SAmAF", "SAmAStrp", "AFAStrp", "SAmAFAStrp"
check_BioGeoBEARS_run(M11s.bay)
## M12s: bay
M12s.bay <- M.test.bay
M12s.bay$lists_of_states_lists_0based[[4]] <- states_list.TS4.M12 # keep "SAm", "AF", "OZ", "AStrp", and combinations…
check_BioGeoBEARS_run(M12s.bay)


## INPUT — DIVA-like
## M3s: diva
M3s.diva <- M.test.diva
M3s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M3 # keep "SAm" only
check_BioGeoBEARS_run(M3s.diva)
## M4s: diva
M4s.diva <- M.test.diva
M4s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M4 # keep "AF"
check_BioGeoBEARS_run(M4s.diva)
## M5s: diva
M5s.diva <- M.test.diva
M5s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M5 # keep SAm", "AF", "SAmAF"
check_BioGeoBEARS_run(M5s.diva)
## M6s: diva
M6s.diva <- M.test.diva
M6s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M6 # keep "SAm", "AF", "OZ", "SAmAF", "SAmOZ", "AFOZ", "SAmAFOZ"
check_BioGeoBEARS_run(M6s.diva)
## M7s: diva
M7s.diva <- M.test.diva
M7s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M7 # keep "AStrp"
check_BioGeoBEARS_run(M7s.diva)
## M8s: diva
M8s.diva <- M.test.diva
M8s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M8 # keep "AStrp", "OZ"
check_BioGeoBEARS_run(M8s.diva)
## M9s: diva
M9s.diva <- M.test.diva
M9s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M9 # keep "NAm", "EU"
check_BioGeoBEARS_run(M9s.diva)
## M10s: diva
M10s.diva <- M.test.diva
M10s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M10 # keep "NAm", "AStrp", "EU"
check_BioGeoBEARS_run(M10s.diva)
## M11s: diva
M11s.diva <- M.test.diva
M11s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M11 # keep "SAm", "AF", "AStrp", "SAmAF", "SAmAStrp", "AFAStrp", "SAmAFAStrp"
check_BioGeoBEARS_run(M11s.diva)
## M12s: diva
M12s.diva <- M.test.diva
M12s.diva$lists_of_states_lists_0based[[4]] <- states_list.TS4.M12 # keep "SAm", "AF", "OZ", "AStrp", and combinations…
check_BioGeoBEARS_run(M12s.diva)
####################################################



####################################################
## RUN test models
####################

## RUN *M.TS*
## run M3.dec
res.M3.dec <- bears_optim_run(M3.dec)
## run M4.dec
res.M4.dec <- bears_optim_run(M4.dec)
## run M5.dec
res.M5.dec <- bears_optim_run(M5.dec)
## run M6.dec
res.M6.dec <- bears_optim_run(M6.dec)
## run M7.dec
res.M7.dec <- bears_optim_run(M7.dec)
## run M8.dec
res.M8.dec <- bears_optim_run(M8.dec)
## run M9.dec
res.M9.dec <- bears_optim_run(M9.dec)
## run M10.dec
res.M10.dec <- bears_optim_run(M10.dec)
## run M11.dec
res.M11.dec <- bears_optim_run(M11.dec)
## run M12.dec
res.M12.dec <- bears_optim_run(M12.dec)
save.image("allApocynaceae_BioGeoBears_results.RData")

## run M3.bay
res.M3.bay <- bears_optim_run(M3.bay)
## run M4.bay
res.M4.bay <- bears_optim_run(M4.bay)
## run M5.bay
res.M5.bay <- bears_optim_run(M5.bay)
## run M6.bay
res.M6.bay <- bears_optim_run(M6.bay)
## run M7.bay
res.M7.bay <- bears_optim_run(M7.bay)
## run M8.bay
res.M8.bay <- bears_optim_run(M8.bay)
## run M9.bay
res.M9.bay <- bears_optim_run(M9.bay)
## run M10.bay
res.M10.bay <- bears_optim_run(M10.bay)
## run M11.bay
res.M11.bay <- bears_optim_run(M11.bay)
## run M12.bay
res.M12.bay <- bears_optim_run(M12.bay)
save.image("allApocynaceae_BioGeoBears_results.RData")

## run M3.diva
res.M3.diva <- bears_optim_run(M3.diva)
## run M4.diva
res.M4.diva <- bears_optim_run(M4.diva)
## run M5.diva
res.M5.diva <- bears_optim_run(M5.diva)
## run M6.diva
res.M6.diva <- bears_optim_run(M6.diva)
## run M7.diva
res.M7.diva <- bears_optim_run(M7.diva)
## run M8.diva
res.M8.diva <- bears_optim_run(M8.diva)
## run M9.diva
res.M9.diva <- bears_optim_run(M9.diva)
## run M10.diva
res.M10.diva <- bears_optim_run(M10.diva)
## run M11.diva
res.M11.diva <- bears_optim_run(M11.diva)
## run M12.diva
res.M12.diva <- bears_optim_run(M12.diva)
save.image("allApocynaceae_BioGeoBears_results.RData")



## RUN *M.TS.s*
## run M3s.dec
res.M3s.dec <- bears_optim_run(M3s.dec)
## run M4s.dec
res.M4s.dec <- bears_optim_run(M4s.dec)
## run M5s.dec
res.M5s.dec <- bears_optim_run(M5s.dec)
## run M6s.dec
res.M6s.dec <- bears_optim_run(M6s.dec)
## run M7s.dec
res.M7s.dec <- bears_optim_run(M7s.dec)
## run M8s.dec
res.M8s.dec <- bears_optim_run(M8s.dec)
## run M9s.dec
res.M9s.dec <- bears_optim_run(M9s.dec)
## run M10s.dec
res.M10s.dec <- bears_optim_run(M10s.dec)
## run M11s.dec
res.M11s.dec <- bears_optim_run(M11s.dec)
## run M12s.dec
res.M12s.dec <- bears_optim_run(M12s.dec)
save.image("allApocynaceae_BioGeoBears_results.RData")

## run M3s.bay
res.M3s.bay <- bears_optim_run(M3s.bay)
## run M4s.bay
res.M4s.bay <- bears_optim_run(M4s.bay)
## run M5s.bay
res.M5s.bay <- bears_optim_run(M5s.bay)
## run M6s.bay
res.M6s.bay <- bears_optim_run(M6s.bay)
## run M7s.bay
res.M7s.bay <- bears_optim_run(M7s.bay)
## run M8s.bay
res.M8s.bay <- bears_optim_run(M8s.bay)
## run M9s.bay
res.M9s.bay <- bears_optim_run(M9s.bay)
## run M10s.bay
res.M10s.bay <- bears_optim_run(M10s.bay)
## run M11s.bay
res.M11s.bay <- bears_optim_run(M11s.bay)
## run M12s.bay
res.M12s.bay <- bears_optim_run(M12s.bay)
save.image("allApocynaceae_BioGeoBears_results.RData")

## run M3s.diva
res.M3s.diva <- bears_optim_run(M3s.diva)
## run M4s.diva
res.M4s.diva <- bears_optim_run(M4s.diva)
## run M5s.diva
res.M5s.diva <- bears_optim_run(M5s.diva)
## run M6s.diva
res.M6s.diva <- bears_optim_run(M6s.diva)
## run M7s.diva
res.M7s.diva <- bears_optim_run(M7s.diva)
## run M8s.diva
res.M8s.diva <- bears_optim_run(M8s.diva)
## run M9s.diva
res.M9s.diva <- bears_optim_run(M9s.diva)
## run M10s.diva
res.M10s.diva <- bears_optim_run(M10s.diva)
## run M11s.diva
res.M11s.diva <- bears_optim_run(M11s.diva)
## run M12s.diva
res.M12s.diva <- bears_optim_run(M12s.diva)
save.image("allApocynaceae_BioGeoBears_results.RData")
####################################################



####################################################
## plot results
####################
setwd(wdp)

## Plot the results for the *M.TS* models

## DEC
## M3.dec
title.plot <- "DEC on Apocynaceae M3_stratified_selectedRanges"
pdf("Rplot_DEC_M3_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M3.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M3.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M4.dec
title.plot <- "DEC on Apocynaceae M4_stratified_selectedRanges"
pdf("Rplot_DEC_M4_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M4.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M4.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M5.dec
title.plot <- "DEC on Apocynaceae M5_stratified_selectedRanges"
pdf("Rplot_DEC_M5_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M5.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M5.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M6.dec
title.plot <- "DEC on Apocynaceae M6_stratified_selectedRanges"
pdf("Rplot_DEC_M6_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M6.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M6.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()
## M7.dec
title.plot <- "DEC on Apocynaceae M7_stratified_selectedRanges"
pdf("Rplot_DEC_M7_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M7.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M7.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M8.dec
title.plot <- "DEC on Apocynaceae M8_stratified_selectedRanges"
pdf("Rplot_DEC_M8_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M8.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M8.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M9.dec
title.plot <- "DEC on Apocynaceae M9_stratified_selectedRanges"
pdf("Rplot_DEC_M9_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M9.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M9.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M10.dec
title.plot <- "DEC on Apocynaceae M10_stratified_selectedRanges"
pdf("Rplot_DEC_M10_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M10.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M10.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M11.dec
title.plot <- "DEC on Apocynaceae M11_stratified_selectedRanges"
pdf("Rplot_DEC_M11_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M11.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M11.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M12.dec
title.plot <- "DEC on Apocynaceae M12_stratified_selectedRanges"
pdf("Rplot_DEC_M12_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M12.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M12.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()



## BAY
## M3.bay
title.plot <- "BAY on Apocynaceae M3_stratified_selectedRanges"
pdf("Rplot_BAY_M3_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M3.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M3.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M4.bay
title.plot <- "BAY on Apocynaceae M4_stratified_selectedRanges"
pdf("Rplot_BAY_M4_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M4.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M4.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M5.bay
title.plot <- "BAY on Apocynaceae M5_stratified_selectedRanges"
pdf("Rplot_BAY_M5_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M5.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M5.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M6.bay
title.plot <- "BAY on Apocynaceae M6_stratified_selectedRanges"
pdf("Rplot_BAY_M6_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M6.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M6.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()
## M7.bay
title.plot <- "BAY on Apocynaceae M7_stratified_selectedRanges"
pdf("Rplot_BAY_M7_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M7.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M7.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M8.bay
title.plot <- "BAY on Apocynaceae M8_stratified_selectedRanges"
pdf("Rplot_BAY_M8_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M8.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M8.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M9.bay
title.plot <- "BAY on Apocynaceae M9_stratified_selectedRanges"
pdf("Rplot_BAY_M9_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M9.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M9.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M10.bay
title.plot <- "BAY on Apocynaceae M10_stratified_selectedRanges"
pdf("Rplot_BAY_M10_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M10.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M10.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M11.bay
title.plot <- "BAY on Apocynaceae M11_stratified_selectedRanges"
pdf("Rplot_BAY_M11_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M11.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M11.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M12.bay
title.plot <- "BAY on Apocynaceae M12_stratified_selectedRanges"
pdf("Rplot_BAY_M12_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M12.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M12.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()




## DIVA
## M3.diva
title.plot <- "DIVA on Apocynaceae M3_stratified_selectedRanges"
pdf("Rplot_DIVA_M3_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M3.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M3.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M4.diva
title.plot <- "DIVA on Apocynaceae M4_stratified_selectedRanges"
pdf("Rplot_DIVA_M4_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M4.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M4.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M5.diva
title.plot <- "DIVA on Apocynaceae M5_stratified_selectedRanges"
pdf("Rplot_DIVA_M5_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M5.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M5.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M6.diva
title.plot <- "DIVA on Apocynaceae M6_stratified_selectedRanges"
pdf("Rplot_DIVA_M6_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M6.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M6.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()
## M7.diva
title.plot <- "DIVA on Apocynaceae M7_stratified_selectedRanges"
pdf("Rplot_DIVA_M7_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M7.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M7.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M8.diva
title.plot <- "DIVA on Apocynaceae M8_stratified_selectedRanges"
pdf("Rplot_DIVA_M8_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M8.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M8.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M9.diva
title.plot <- "DIVA on Apocynaceae M9_stratified_selectedRanges"
pdf("Rplot_DIVA_M9_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M9.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M9.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M10.diva
title.plot <- "DIVA on Apocynaceae M10_stratified_selectedRanges"
pdf("Rplot_DIVA_M10_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M10.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M10.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M11.diva
title.plot <- "DIVA on Apocynaceae M11_stratified_selectedRanges"
pdf("Rplot_DIVA_M11_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M11.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M11.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M12.diva
title.plot <- "DIVA on Apocynaceae M12_stratified_selectedRanges"
pdf("Rplot_DIVA_M12_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M12.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M12.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()




## Plot the results for the *M.TS.s* models
## DEC
## M3s.dec
title.plot <- "DEC on Apocynaceae M3s_stratified_selectedRanges"
pdf("Rplot_DEC_M3s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M3s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M3s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M4s.dec
title.plot <- "DEC on Apocynaceae M4s_stratified_selectedRanges"
pdf("Rplot_DEC_M4s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M4s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M4s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M5s.dec
title.plot <- "DEC on Apocynaceae M5s_stratified_selectedRanges"
pdf("Rplot_DEC_M5s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M5s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M5s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M6s.dec
title.plot <- "DEC on Apocynaceae M6s_stratified_selectedRanges"
pdf("Rplot_DEC_M6s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M6s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M6s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()
## M7s.dec
title.plot <- "DEC on Apocynaceae M7s_stratified_selectedRanges"
pdf("Rplot_DEC_M7s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M7s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M7s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M8s.dec
title.plot <- "DEC on Apocynaceae M8s_stratified_selectedRanges"
pdf("Rplot_DEC_M8s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M8s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M8s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M9s.dec
title.plot <- "DEC on Apocynaceae M9s_stratified_selectedRanges"
pdf("Rplot_DEC_M9s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M9s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M9s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M10s.dec
title.plot <- "DEC on Apocynaceae M10s_stratified_selectedRanges"
pdf("Rplot_DEC_M10s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M10s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M10s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M11s.dec
title.plot <- "DEC on Apocynaceae M11s_stratified_selectedRanges"
pdf("Rplot_DEC_M11s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M11s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M11s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M12s.dec
title.plot <- "DEC on Apocynaceae M12s_stratified_selectedRanges"
pdf("Rplot_DEC_M12s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M12s.dec, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M12s.dec, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()



## BAY
## M3s.bay
title.plot <- "BAY on Apocynaceae M3s_stratified_selectedRanges"
pdf("Rplot_BAY_M3s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M3s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M3s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M4s.bay
title.plot <- "BAY on Apocynaceae M4s_stratified_selectedRanges"
pdf("Rplot_BAY_M4s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M4s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M4s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M5s.bay
title.plot <- "BAY on Apocynaceae M5s_stratified_selectedRanges"
pdf("Rplot_BAY_M5s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M5s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M5s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M6s.bay
title.plot <- "BAY on Apocynaceae M6s_stratified_selectedRanges"
pdf("Rplot_BAY_M6s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M6s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M6s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()
## M7s.bay
title.plot <- "BAY on Apocynaceae M7s_stratified_selectedRanges"
pdf("Rplot_BAY_M7s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M7s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M7s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M8s.bay
title.plot <- "BAY on Apocynaceae M8s_stratified_selectedRanges"
pdf("Rplot_BAY_M8s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M8s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M8s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M9s.bay
title.plot <- "BAY on Apocynaceae M9s_stratified_selectedRanges"
pdf("Rplot_BAY_M9s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M9s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M9s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M10s.bay
title.plot <- "BAY on Apocynaceae M10s_stratified_selectedRanges"
pdf("Rplot_BAY_M10s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M10s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M10s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M11s.bay
title.plot <- "BAY on Apocynaceae M11s_stratified_selectedRanges"
pdf("Rplot_BAY_M11s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M11s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M11s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M12s.bay
title.plot <- "BAY on Apocynaceae M12s_stratified_selectedRanges"
pdf("Rplot_BAY_M12s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M12s.bay, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M12s.bay, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()




## DIVA
## M3s.diva
title.plot <- "DIVA on Apocynaceae M3s_stratified_selectedRanges"
pdf("Rplot_DIVA_M3s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M3s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M3s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M4s.diva
title.plot <- "DIVA on Apocynaceae M4s_stratified_selectedRanges"
pdf("Rplot_DIVA_M4s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M4s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M4s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M5s.diva
title.plot <- "DIVA on Apocynaceae M5s_stratified_selectedRanges"
pdf("Rplot_DIVA_M5s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M5s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M5s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M6s.diva
title.plot <- "DIVA on Apocynaceae M6s_stratified_selectedRanges"
pdf("Rplot_DIVA_M6s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M6s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M6s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()
## M7s.diva
title.plot <- "DIVA on Apocynaceae M7s_stratified_selectedRanges"
pdf("Rplot_DIVA_M7s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M7s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M7s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M8s.diva
title.plot <- "DIVA on Apocynaceae M8s_stratified_selectedRanges"
pdf("Rplot_DIVA_M8s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M8s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M8s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M9s.diva
title.plot <- "DIVA on Apocynaceae M9s_stratified_selectedRanges"
pdf("Rplot_DIVA_M9s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M9s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M9s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M10s.diva
title.plot <- "DIVA on Apocynaceae M10s_stratified_selectedRanges"
pdf("Rplot_DIVA_M10s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M10s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M10s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M11s.diva
title.plot <- "DIVA on Apocynaceae M11s_stratified_selectedRanges"
pdf("Rplot_DIVA_M11s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M11s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M11s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

## M12s.diva
title.plot <- "DIVA on Apocynaceae M12s_stratified_selectedRanges"
pdf("Rplot_DIVA_M12s_stratified_selRanges.pdf", width = 20, height = 100)

## States
plot_BioGeoBEARS_results(res.M12s.diva, analysis_titletxt = title.plot, plotwhat = "text", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
## Pie chart
plot_BioGeoBEARS_results(res.M12s.diva, analysis_titletxt = title.plot, plotwhat = "pie", 
                         tr = tr, tipranges = tipranges, cornercoords_loc = scriptdir, addl_params=list("j"), include_null_range = TRUE, 
                         label.offset = 0.45, tipcex = 0.4, statecex = 0.5, splitcex = 0.4, titlecex = 1.2, 
                         plotsplits = FALSE)
dev.off()

setwd(wd)
####################################################

## END RUN script 2: fit hypothesis tests


